@@ -3,7 +3,7 @@ from enum import IntEnum
 
 class AppAlgorithmType(IntEnum):
     """
-    应用秘钥类型
+    App algorithm type
     """
     AppAlgorithmType_Not = 0
     AppAlgorithmType_SM2 = 1  # SM2
@@ -13,15 +13,15 @@ class AppAlgorithmType(IntEnum):
 
 class AppCaType(IntEnum):
     """
-    应用秘钥托管类型
+    Type of key mode
     """
     AppCaType_Not = 0
-    AppCaType_Trust = 1  # 托管
-    AppCaType_NoTrust = 2  # 非托管
+    AppCaType_Trust = 1  # Key-Trust Mode
+    AppCaType_NoTrust = 2  # Public-Key-Upload Mode
 
 class ResCode(IntEnum):
     """
-       应用秘钥托管类型
+       Type of key mode
        """
-    ResCode_Suc = 0  # 校验成功
-    ResCode_Fail = -1  # 校验失败
+    ResCode_Suc = 0  # success
+    ResCode_Fail = -1  # failure
