@@ -6,7 +6,7 @@ from bsn_sdk_py.until.tools import nonce_str, array_sort, map_sort, obj_sort
 
 class GetLedgerInfo(BsnBase):
     """
-    获取最新账本信息
+    get ledger info 
     """
     def __init__(self):
         pass
@@ -19,9 +19,9 @@ class GetLedgerInfo(BsnBase):
 
 
     def sign(self, body):
-        # 拼接待签名的字符串
+        # assemble character string to sign
         sign_str = self.config.user_code + self.config.app_code
-        # 对字符串 使用用户私钥证书进行 SHA256WITHECDSA 签名，调用ecdsa_sign方法生成base64格式mac值
+        # The string is signed with SHA256WITHECDSA using the user's private key certificate, and the ecdsa_sign method is called to generate base64-formatted MAC values.
         mac = self.config.encrypt_sign.sign(sign_str).decode()
         return mac
 
@@ -31,5 +31,5 @@ class GetLedgerInfo(BsnBase):
                      str(res_data['body']["preBlockHash"])
 
         signature = res_data['mac']
-        # 调用ecdsa_verify方法，进行验签
+        # Call the ecdsa_verify function to verify the signature
         return self.config.encrypt_sign.verify(verify_str, signature)
\ No newline at end of file
